@@ -335,14 +335,7 @@ end = struct
 
   let scan_cmis =
     let new_cmis = ref [] in
-    let default_load = !Persistent_env.Persistent_signature.load in
-    let load ~unit_name =
-      let res = default_load ~unit_name in
-      (match res with None -> () | Some x -> new_cmis := x.cmi :: !new_cmis);
-      res
-    in
-    Persistent_env.Persistent_signature.load := load;
-
+    UTop_compat.add_cmi_hook (fun cmi -> new_cmis := cmi :: !new_cmis );
     fun pp ->
       List.iter (fun (cmi : Cmi_format.cmi_infos) ->
         walk_sig pp ~path:(Longident.Lident cmi.cmi_name) cmi.cmi_sign
@@ -567,7 +560,7 @@ let rewrite_rules = [
       with_default_loc loc (fun () ->
         Exp.apply
           (Exp.ident (with_loc loc longident_async_thread_safe_block_on_async_exn))
-          [(Nolabel, Exp.fun_ Nolabel None punit e)]
+          [(Nolabel, UTop_compat.Exp.fun_ ~loc punit e)]
       )
     );
     enabled = UTop.auto_run_async;
@@ -582,10 +575,10 @@ let rule_path rule =
       let env = !Toploop.toplevel_env in
       let path =
         match Env.find_type_by_name rule.type_to_rewrite env with
-        | path, { Types.type_kind     = Types.Type_abstract
+        | path, { Types.type_kind     = type_kind
                 ; Types.type_private  = Asttypes.Public
                 ; Types.type_manifest = Some ty
-                } -> begin
+                } when type_kind = UTop_compat.abstract_type_kind -> begin
             match get_desc (Ctype.expand_head env ty) with
             | Types.Tconstr (path, _, _) -> path
             | _ -> path
@@ -1545,7 +1538,8 @@ let interact ?(search_path=[]) ?(build_dir="_build") ~unit ~loc:(fname, lnum, cn
   let search_path = walk build_dir ~init:search_path ~f:(fun dir acc -> dir :: acc) in
   let cmt_fname =
     try
-      Misc.find_in_path_uncap search_path (unit ^ ".cmt")
+      UTop_compat.find_in_path_normalized
+        search_path (unit ^ ".cmt")
     with Not_found ->
       Printf.ksprintf failwith "%s.cmt not found in search path!" unit
   in
@@ -1577,7 +1571,8 @@ let interact ?(search_path=[]) ?(build_dir="_build") ~unit ~loc:(fname, lnum, cn
     failwith "Couldn't find location in cmt file"
   with Found env ->
   try
-    List.iter Topdirs.dir_directory (search_path @ cmt_infos.cmt_loadpath);
+    let visible_paths = UTop_compat.visible_paths_for_cmt_infos cmt_infos in
+    List.iter Topdirs.dir_directory (search_path @ visible_paths);
     let env = Envaux.env_of_only_summary env in
     List.iter (fun (V (name, v)) -> Toploop.setvalue name (Obj.repr v)) values;
     main_internal ~initial_env:(Some env)
